Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(899)

Unified Diff: src/objects.h

Issue 2493823003: [wasm] Allocate a single script per wasm module (Closed)
Patch Set: rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/messages.cc ('k') | src/objects.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index 1cc325bb6501743b6e6be0e2602281ccb1b52c1e..2f2d537ffd597102eabab7c52757243a96cd675e 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -7084,13 +7084,9 @@ class Script: public Struct {
// [source_mapping_url]: sourceMappingURL magic comment
DECL_ACCESSORS(source_mapping_url, Object)
// [wasm_instance]: the wasm instance this script belongs to.
// This must only be called if the type of this script is TYPE_WASM.
- DECL_ACCESSORS(wasm_instance, JSObject)
-
- // [wasm_function_index]: the wasm function index this script belongs to.
- // This must only be called if the type of this script is TYPE_WASM.
- DECL_INT_ACCESSORS(wasm_function_index)
+ DECL_ACCESSORS(wasm_compiled_module, Object)
// [compilation_type]: how the the script was compiled. Encoded in the
// 'flags' field.
« no previous file with comments | « src/messages.cc ('k') | src/objects.cc » ('j') | no next file with comments »
@@ -7084,13 +7084,9 @@ class Script: public Struct {
// [source_mapping_url]: sourceMappingURL magic comment
DECL_ACCESSORS(source_mapping_url, Object)
- // [wasm_instance]: the wasm instance this script belongs to.
+ // [wasm_compiled_module]: the compiled wasm module this script belongs to.
// This must only be called if the type of this script is TYPE_WASM.

Powered by Google App Engine
This is Rietveld 408576698